@@ -1245,6 +1245,52 @@ class DbbrainClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def UpdateAgentSwitch(self, request):
+        """更新agent状态（停止或重连Agent）
+
+        :param request: Request instance for UpdateAgentSwitch.
+        :type request: :class:`tencentcloud.dbbrain.v20210527.models.UpdateAgentSwitchRequest`
+        :rtype: :class:`tencentcloud.dbbrain.v20210527.models.UpdateAgentSwitchResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("UpdateAgentSwitch", params, headers=headers)
+            response = json.loads(body)
+            model = models.UpdateAgentSwitchResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def UpdateMonitorSwitch(self, request):
+        """更新Agent实例状态（停止或重连实例）
+
+        :param request: Request instance for UpdateMonitorSwitch.
+        :type request: :class:`tencentcloud.dbbrain.v20210527.models.UpdateMonitorSwitchRequest`
+        :rtype: :class:`tencentcloud.dbbrain.v20210527.models.UpdateMonitorSwitchResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("UpdateMonitorSwitch", params, headers=headers)
+            response = json.loads(body)
+            model = models.UpdateMonitorSwitchResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def VerifyUserAccount(self, request):
         """验证用户数据库账号权限，获取会话token。
 
